@@ -35,6 +35,18 @@
                 name: 'taxonomy',
                 filename: 'sp.taxonomy.DEBUG.js'
             }
+        ],
+        'userprofile' : [
+            {
+                name: 'userprofile',
+                filename: 'sp.userprofiles.debug.js'
+            }
+        ],
+        'publishing' : [
+            {
+                name: 'publishing',
+                filename: 'sp.publishing.debug.js'
+            }
         ]
     }
 
